#dj_dashboard {
    width: 100%;
    float: left;
    padding-top: 14px;
}

.editControl {
    padding-top: 10px;
    width: 20%;
    float: right;
    margin-right: 10px;
}

select {
    width: 85%;
    float: left;
}

i.large.filter.link.icon, i.large.trash.outline.link.icon {
    margin-top: 5px;
    float: right;
    z-index: 1;
}

/* overwrite some grid css */
.grid-stack-item {
    border: silver 1px solid;
}

.grid-stack-item-content {
    overflow: initial;
}

.grid-stack>.grid-stack-item>.grid-stack-item-content {
    overflow: initial !important;
}

.ui-state-disabled {
    opacity: initial;
}
.grid-stack>.grid-stack-item {
    box-shadow: 6px 6px 8px #e6e6e6;
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
}


/***********************************************************************************************/
/* Widget title */
span.widget_title {
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden;
    width: 80%;
    float: left;
    font-size: 24px;
    font-weight: 400;
    font-style: normal;
    text-align: left;
    text-rendering: optimizelegibility;
    line-height: 40px;
    color: inherit;
    margin: 0;
    padding: 0;
    border: 0;
    padding-left: 14px;
}

/***********************************************************************************************/
/* center the content of type table and canvas */
.table,
.canvas {
    margin: auto;
    margin-top: 11px;
}

/* only for canvas reduce it */
.canvas {
    height: 85% !important;
    width: initial !important;
}

.grid-stack-item[data-gs-height="2"]>.grid-stack-item-content>.canvas {
    height: 60% !important;
}

.grid-stack-item[data-gs-height="3"]>.grid-stack-item-content>.canvas {
    height: 75% !important;
}

.grid-stack-item[data-gs-height="4"]>.grid-stack-item-content>.canvas {
    height: 80% !important;
}

/* center the loading icons*/
.load_center {
    position: absolute;
    top: 50%;
    transform: translateY(-50%);
    left: 50%;
}

/* only for the 1 space width */
.grid-stack > .grid-stack-item[data-gs-width='1'] > .grid-stack-item-content > .canvas {height: 75% !important;}
/***********************************************************************************************/
/* grid-stack horizontal space */
.grid-stack > .grid-stack-item[data-gs-width='1'] {width: 7%;}
.grid-stack > .grid-stack-item[data-gs-x='1'] {left:  10%;}

.grid-stack > .grid-stack-item[data-gs-width='2'] {width: 15%;}
.grid-stack > .grid-stack-item[data-gs-x='2'] {left: 17%;}

.grid-stack > .grid-stack-item[data-gs-width='3'] {width: 24%;}
.grid-stack > .grid-stack-item[data-gs-x='3'] {left: 26%;}

.grid-stack > .grid-stack-item[data-gs-width='4'] {width: 31%;}
.grid-stack > .grid-stack-item[data-gs-x='4'] {left: 33%;}

.grid-stack > .grid-stack-item[data-gs-width='5'] {width: 41%;}
.grid-stack > .grid-stack-item[data-gs-x='5'] {left: 43%;}

.grid-stack > .grid-stack-item[data-gs-width='6'] {width: 49%;}
.grid-stack > .grid-stack-item[data-gs-x='6'] {left: 51%;}

.grid-stack > .grid-stack-item[data-gs-width='7'] {width: 57%;}
.grid-stack > .grid-stack-item[data-gs-x='7'] {left: 59%;}

.grid-stack > .grid-stack-item[data-gs-width='8'] {width: 67%;}
.grid-stack > .grid-stack-item[data-gs-x='8'] {left: 69%;}

.grid-stack > .grid-stack-item[data-gs-width='9'] {width: 74%;}
.grid-stack > .grid-stack-item[data-gs-x='9'] {left: 76%;}

.grid-stack > .grid-stack-item[data-gs-width='10'] {width: 83%;}
.grid-stack > .grid-stack-item[data-gs-x='10'] {left: 85%;}

.grid-stack > .grid-stack-item[data-gs-width='11'] {width: 90%;}
.grid-stack > .grid-stack-item[data-gs-x='11'] {left: 92%;}

.grid-stack > .grid-stack-item[data-gs-width='12'] {width: 100%;}
.grid-stack > .grid-stack-item[data-gs-x='12'] {left: 102%;}
