# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-11-24 10:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dj_dashboard', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboard',
            name='enable_edit',
            field=models.BooleanField(default=True, verbose_name='Enable Edit'),
        ),
    ]
