# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-10-17 10:28
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Dashboard',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('dashboard_reverse_name', models.CharField(blank=True, max_length=300, null=True, verbose_name='Dashboard reverse name')),
                ('position_y', models.IntegerField(blank=True, default=0, verbose_name='Element position Y')),
                ('position_x', models.IntegerField(blank=True, default=0, verbose_name='Element position X')),
                ('width', models.IntegerField(blank=True, default=12, verbose_name='Widget width')),
                ('height', models.IntegerField(blank=True, default=2, verbose_name='Widget height')),
                ('widget_reverse_name', models.CharField(blank=True, max_length=300, null=True, verbose_name='Content reverse name')),
                ('widget_args', models.CharField(blank=True, max_length=300, null=True, verbose_name='Content args')),
                ('user', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dj_dashboard_dashboard_users', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Dashboard',
                'verbose_name_plural': 'Dashboards',
            },
        ),
    ]
